****************
Reference Manual
****************

To learn how to use Project, we recommend the `Getting Started
Guide`_, followed by the online help features (e.g. tab complete in
the Notebook), along with the `User Guide`_.

Even so, for a truly comprehensive reference to every object in
Project, we provide this reference manual. The reference manual is
generated directly from documentation and declarations in the source
code, and is thus often much more verbose than necessary, because many
little-used yet often-duplicated methods are listed for each class.
Still, the reference for a given component does provide a
comprehensive listing of all attributes and methods, inherited or
otherwise, which can be difficult to obtain from the source code
directly.


`An overview of all modules within all subpackages of HoloViews: <holoviews.html>`_


HoloViews subpackages
---------------------

`core`_
 Base classes implementing the core data structures of HoloViews.
`element`_
 Elements that form the basis of more complex visualizations.

.. toctree::
   :maxdepth: 2
   :hidden:

   core <holoviews.core>
   element <holoviews.element>

.. _Getting Started Guide: ../getting_started/index.html
.. _User Guide: ../user_guide/index.html
.. _core: holoviews.core.html
.. _element: holoviews.element.html
